==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/Ipv6PrefixSpecification.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Ipv6PrefixSpecification(
    ipv6Prefix: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification = {
    import Ipv6PrefixSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
      .builder()
      .optionallyWith(ipv6Prefix.map(value => value: java.lang.String))(
        _.ipv6Prefix
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly =
    zio.aws.ec2.model.Ipv6PrefixSpecification.wrap(buildAwsValue())
}
object Ipv6PrefixSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Ipv6PrefixSpecification =
      zio.aws.ec2.model.Ipv6PrefixSpecification(ipv6Prefix.map(value => value))
    def ipv6Prefix: Optional[String]
    def getIpv6Prefix: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Prefix", ipv6Prefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ) extends zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly {
    override val ipv6Prefix: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ipv6Prefix())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ): zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/Ipv6PrefixSpecification.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Ipv6PrefixSpecification(ipv6Prefix: Option[String] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification = {
    import Ipv6PrefixSpecification.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
      .builder()
      .optionallyWith(ipv6Prefix.map(value => value: java.lang.String))(
        _.ipv6Prefix
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly =
    zio.aws.ec2.model.Ipv6PrefixSpecification.wrap(buildAwsValue())
}
object Ipv6PrefixSpecification {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.Ipv6PrefixSpecification =
      zio.aws.ec2.model.Ipv6PrefixSpecification(ipv6Prefix.map(value => value))
    def ipv6Prefix: Option[String]
    def getIpv6Prefix: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ipv6Prefix", ipv6Prefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ) extends zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly {
    override val ipv6Prefix: Option[String] =
      scala.Option(impl.ipv6Prefix()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.Ipv6PrefixSpecification
  ): zio.aws.ec2.model.Ipv6PrefixSpecification.ReadOnly = new Wrapper(impl)
}
